@@ -11,11 +11,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""
-| OpenJij response class.
+"""| OpenJij response class.
+
 | The usage is almost the same as :class:`dimod.SampleSet`.
 """
-
+from __future__ import annotations
 import dimod
 
 
